# Revit UI Reset Tool

This repository provides a PowerShell script (`ResetRevitUI.ps1`) to reset the user interface settings for Autodesk Revit. It allows you to automatically close Revit, rename the `UIState.dat` file (which stores the UI settings), and relaunch Revit with default UI settings.

## Repository

- Git URL: [https://git.nixc.us/colin/revit-ui-reset/](https://git.nixc.us/colin/revit-ui-reset/)
- Raw script file: [ResetRevitUI.ps1](https://git.nixc.us/colin/revit-ui-reset/raw/branch/main/ResetRevitUI.ps1)

## Features

- **Automatically closes Revit** if it is running.
- **Renames the ****`UIState.dat`**** file** to reset Revit UI settings.
- **Relaunches Revit** with default settings, making it easier to troubleshoot UI issues.

## Usage

### Prerequisites

- Windows operating system.
- Autodesk Revit 2024 (or other recent versions).
- Administrator privileges to run the script.

### How to Use

1. **Download the Script**

   - Visit the following link to download the script directly: [ResetRevitUI.ps1](https://git.nixc.us/colin/revit-ui-reset/raw/branch/main/ResetRevitUI.ps1)
   - Save the script to a known location on your computer (e.g., Downloads folder).

2. **Run the PowerShell Script**

   - Open PowerShell with Administrator privileges:
     - Press `Windows + S`, type "PowerShell", right-click on **Windows PowerShell**, and select **Run as Administrator**.
   - Navigate to the directory where you saved the script. For example:
     ```powershell
     cd "$env:USERPROFILE\Downloads"
     ```
   - Execute the script:
     ```powershell
     .\ResetRevitUI.ps1
     ```

   The script will:

   - Close any running instance of Revit.
   - Rename the `UIState.dat` file to `UIState.dat.bak`.
   - Relaunch Revit.

### Undoing the Changes

If you want to undo the changes made by the script:

1. **Close Revit** if it is running.
2. **Rename the ****`UIState.dat.bak`**** file** back to `UIState.dat`:
   - Navigate to the folder `%APPDATA%\Autodesk\Revit\Revit 2024` (or the relevant version).
   - Find the `UIState.dat.bak` file.
   - Rename it back to `UIState.dat`.
3. **Relaunch Revit**.

### Notes

- Make sure Revit is not running important unsaved projects before running the script, as it will forcibly close Revit.
- The script will attempt to find the latest version of Revit installed by looking in the `%APPDATA%` folder.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Contributions

Contributions are welcome! Feel free to submit a pull request or open an issue to suggest improvements or report bugs.

## Contact

For any questions or suggestions, please contact [Colin](mailto\:colin@example.com).

